package v1

import (
	"github.com/gin-gonic/gin"
)

import (
	"auth-server/common"
	"auth-server/service"
)

func Ping(c *gin.Context) {
	common.HttpSuccess(c, "pong")
}

func SoftwareInfo(c *gin.Context) {
	si := service.GetSoftwareInfo()
	common.HttpSuccess(c, map[string]interface{}{
		"server": map[string]interface{}{
			"auth-server": map[string]interface{}{
				"desc":    common.Desc,
				"build":   common.Build,
				"version": common.Version,
			},
			"resource-server": map[string]interface{}{
				"desc":    si.GetDesc(),
				"build":   si.GetBuild(),
				"version": si.GetVersion(),
			},
		},
		"language": common.MetadataConfig.GetLanguages(),
	})
}

func Login(c *gin.Context) {
	request := &struct {
		Username string `json:"username" binding:"required"`
		Password string `json:"password" binding:"required"`
	}{}
	if err := c.ShouldBindJSON(request); err != nil {
		common.HttpErr(c, err)
		return
	}
	res, err := service.Login(request.Username, request.Password)
	if err != nil {
		common.HttpErr(c, err)
		return
	}
	common.HttpSuccess(c, res)
}
